

import 'package:clean_application/clean_application.dart';

import '../data/datasources/user_datasource.dart';
import '../data/datasources/user_datasource_prod.dart';
import '../data/datasources/user_fake_datasource.dart';
import '../data/repositories/user_repository_impl.dart';
import '../domain/repository_contracts/user_repository.dart';
import '../domain/usecases/get_user_usecase.dart';
import '../domain/usecases/get_users_usecase.dart';
import '../presentation/home_controller.dart';

class AppConfiguration implements Configuration {

  @override
  List<Controller> controllersProvider() {
    return [
      HomeController(),
      CounterController(),
      ColorController(),
    ];
  }

  @override
  List<UseCase> useCasesProvider() {
    return [
      GetUserUseCase(),
      GetUsersUseCase(),
    ];
  }

  @override
  List<InstanceProvider<DataSource>> dataSourcesProvider(String environment) {
    return [
      InstanceProvider<UserDataSource>(
        value: () => environment == Environments.Development ? UserFakeDataSource() : UserDataSourceProduction(),
      ),
    ];
  }

  @override
  List<InstanceProvider<Repository>> repositoriesProvider(String environment) {
    return [
      InstanceProvider<UserRepository>(
        value: () => UserRepositoryImpl(CleanApplication.datasource<UserDataSource>()),
      ),
    ];
  }

}
