import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

/// Controller class that hold a View business logic
abstract class Controller<C>{
  ValueNotifier _valueNotifier;
  bool _initialized = false;

  Controller() {
    _valueNotifier = ValueNotifier(false);
    _initialized = false;
  }

  ValueNotifier get notifier => _valueNotifier;

  /// Called when the View init state is mounted
  /// This can be overrided to perform some initialization tasks
  Future<void> initialize() async {
    await onInitialize();
    _initialized = true;
    rebuild();
  }

  Future onInitialize();

  bool get isInitialized => _initialized == true;

  /// Use to explicitly rebuild a view from the controller.
  /// Not recommended because of separation of *concerns
  void rebuild() {
    setState(() => null);
  }

  /// Call a controller method
  /// And then notify listeners
  void setState(VoidCallback callback) {
    if (callback != null) {
      callback();
    }

    _valueNotifier.value = !_valueNotifier.value;
  }
}
