import 'package:clean_application/src/presentation/clean_application.dart';
import 'package:clean_application/src/presentation/controller.dart';
import 'package:flutter/material.dart';

abstract class View<C extends Controller> extends StatefulWidget {

  final bool _listen;

  const View({Key key, bool listen = true}) : _listen = listen, super(key: key);

  C getController() {
    return CleanApplication.controller<C>('$C');
  }

  C get controller => getController();

  bool get isListening => _listen;

  Widget build(BuildContext context, C controller);

  @override
  _ViewState<C> createState() => _ViewState<C>();
}

class _ViewState<C extends Controller> extends State<View<C>> {
  C _controller;

  @override
  void initState() {
    super.initState();

    _controller = CleanApplication.controller<C>('$C');

    initialize();
  }

  Future<void> initialize() async {
    if(mounted){
      await _controller.initialize();
      setState(() {});
    }
  }

  @override
  Widget build(BuildContext context) {
    if(widget._listen){
      return ValueListenableBuilder(
        valueListenable: _controller.notifier,
        builder: (context, value, child) {
          return widget.build(context, _controller);
        },
      );
    }

    return widget.build(context, _controller);
  }
}
