
import 'package:flutter/foundation.dart';

/// A wrapper class to provide Interfaces/Contracts (abstract class) implementations
/// to the application according to, for example, the environment.
///
/// All interfaces are instanciated at the registration time, so avoid have task
/// on the constructors.
///
/// This is intended mainly for [DataSource] and [Repository] implementations.
///
/// TODO: This can be improved with lazy singleton?
class InstanceProvider<T> {

  final T Function() value;

  InstanceProvider({@required this.value,}) : assert(value != null);

  String name() => '$T';

  T instanciate(){
    return value();
  }

}
